@@ -1,8 +1,8 @@
 package ExtUtils::ModuleMaker::Defaults;
-# as of 09-04-2005
+# as of 09-05-2005
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 my $usage = <<ENDOFUSAGE;
 
@@ -13,7 +13,7 @@ ENDOFUSAGE
 
 my %default_values = (
         LICENSE          => 'perl',
-        VERSION          => 0.01,
+        VERSION          => '0.01',
         ABSTRACT         => 'Module abstract (<= 44 characters) goes here',
         AUTHOR           => 'A. U. Thor',
         CPANID           => 'MODAUTHOR',
@@ -37,4 +37,23 @@ sub default_values {
     return { %default_values };
 }
 
+=head1 NAME
+
+ExtUtils::ModuleMaker::Defaults - Default values for ExtUtils::ModuleMaker objects
+
+=head1 METHODS
+
+=head3 C<default_values()>
+
+  Usage     : $self->default_values() within new(); within
+              ExtUtils::ModuleMaker::Interactive::_prepare_author_defaults() 
+              and _prepare_directives_defaults(); 
+              within t/testlib/Testing/Defaults.pm
+  Purpose   : Set the default values for ExtUtils::ModuleMaker object elements
+  Returns   : Reference to a hash of default values
+  Argument  : n/a
+  Comment   : Can be overridden by establishing a Personal::Defaults file.
+
+=cut
+
 1;
